@@ -4,6 +4,13 @@ def test_build_bogus_platform(cli):
     assert "Compiling on platform 'foo' is not yet supported" in cli.logged
 
 
+def test_failed_build(cli):
+    cli.run("-tmacos-arm64", "build", "3.12.0")
+    assert cli.failed
+    assert "Error while compiling xz:5.4.5: ForbiddenHttpError" in cli.logged
+    assert "Overall compilation failed:" in cli.logged
+
+
 def test_invalid(cli):
     cli.run("-n", "build", "foo")
     assert cli.failed
